@@ -21,7 +21,7 @@ import warnings
 from abc import ABCMeta
 from collections.abc import Callable, Sequence
 from functools import singledispatch
-from typing import TypeAlias
+from typing import Any, TypeAlias
 
 import numpy as np
 
@@ -86,8 +86,7 @@ class _Unpickling:
 
 class DistributionMeta(ABCMeta):
     """
-    DistributionMeta class
-
+    DistributionMeta class.
 
     Notes
     -----
@@ -194,8 +193,9 @@ class DistributionMeta(ABCMeta):
 
 
 class _class_or_instancemethod(classmethod):
-    """Allow a method to be called both as a classmethod and an instancemethod,
-    giving priority to the instancemethod.
+    """Allow a method to be called both as a classmethod and an instancemethod.
+
+    Priority is given to the instancemethod.
 
     This is used to allow extracting information from the signature of a SymbolicRandomVariable
     which may be provided either as a class attribute or as an instance attribute.
@@ -209,7 +209,7 @@ class _class_or_instancemethod(classmethod):
 
 
 class SymbolicRandomVariable(MeasurableOp, OpFromGraph):
-    """Symbolic Random Variable
+    """Symbolic Random Variable.
 
     This is a subclasse of `OpFromGraph` which is used to encapsulate the symbolic
     random graph of complex distributions which are built on top of pure
@@ -270,7 +270,7 @@ class SymbolicRandomVariable(MeasurableOp, OpFromGraph):
     @_class_or_instancemethod
     @property
     def ndim_supp(cls_or_self) -> int | None:
-        """Number of support dimensions of the RandomVariable
+        """Number of support dimensions of the RandomVariable.
 
         (0 for scalar, 1 for vector, ...)
         """
@@ -309,7 +309,7 @@ class SymbolicRandomVariable(MeasurableOp, OpFromGraph):
     def get_input_output_type_idxs(
         extended_signature: str | None,
     ) -> tuple[tuple[tuple[int], int | None, tuple[int]], tuple[tuple[int], tuple[int]]]:
-        """Parse extended_signature and return indexes for *[rng], [size] and parameters as well as outputs"""
+        """Parse extended_signature and return indexes for *[rng], [size] and parameters as well as outputs."""
         if extended_signature is None:
             raise ValueError("extended_signature must be provided")
 
@@ -341,17 +341,17 @@ class SymbolicRandomVariable(MeasurableOp, OpFromGraph):
         )
 
     def rng_params(self, node) -> tuple[Variable, ...]:
-        """Extract the rng parameters from the node's inputs"""
+        """Extract the rng parameters from the node's inputs."""
         [rng_args_idxs, _, _], _ = self.get_input_output_type_idxs(self.extended_signature)
         return tuple(node.inputs[i] for i in rng_args_idxs)
 
     def size_param(self, node) -> Variable | None:
-        """Extract the size parameter from the node's inputs"""
+        """Extract the size parameter from the node's inputs."""
         [_, size_arg_idx, _], _ = self.get_input_output_type_idxs(self.extended_signature)
         return node.inputs[size_arg_idx] if size_arg_idx is not None else None
 
     def dist_params(self, node) -> tuple[Variable, ...]:
-        """Extract distribution parameters from the node's inputs"""
+        """Extract distribution parameters from the node's inputs."""
         [_, _, param_args_idxs], _ = self.get_input_output_type_idxs(self.extended_signature)
         return tuple(node.inputs[i] for i in param_args_idxs)
 
@@ -384,7 +384,7 @@ class SymbolicRandomVariable(MeasurableOp, OpFromGraph):
         super().__init__(*args, **kwargs)
 
     def update(self, node: Apply) -> dict[Variable, Variable]:
-        """Symbolic update expression for input random state variables
+        """Symbolic update expression for input random state variables.
 
         Returns a dictionary with the symbolic expressions required for correct updating
         of random state input variables repeated function evaluations. This is used by
@@ -393,7 +393,7 @@ class SymbolicRandomVariable(MeasurableOp, OpFromGraph):
         return collect_default_updates_inner_fgraph(node)
 
     def batch_ndim(self, node: Apply) -> int:
-        """Number of dimensions of the distribution's batch shape."""
+        """Return the number of dimensions of the distribution's batch shape."""
         out_ndim = max(getattr(out.type, "ndim", 0) for out in node.outputs)
         return out_ndim - self.ndim_supp
 
@@ -421,10 +421,14 @@ def change_symbolic_rv_size(op: SymbolicRandomVariable, rv, new_size, expand) ->
 
 
 class Distribution(metaclass=DistributionMeta):
-    """Statistical distribution"""
+    """Statistical distribution."""
 
-    rv_op: [RandomVariable, SymbolicRandomVariable] = None
-    rv_type: MetaType = None
+    # rv_op and _type are set to None via the DistributionMeta.__new__
+    # if not specified as class attributes in subclasses of Distribution.
+    # rv_op can either be a class (see the Normal class) or a method
+    # (see the Censored class), both callable to return a TensorVariable.
+    rv_op: Any = None
+    rv_type: MetaType | None = None
 
     def __new__(
         cls,
@@ -439,7 +443,7 @@ class Distribution(metaclass=DistributionMeta):
         default_transform=UNSET,
         **kwargs,
     ) -> TensorVariable:
-        """Adds a tensor variable corresponding to a PyMC distribution to the current model.
+        """Add a tensor variable corresponding to a PyMC distribution to the current model.
 
         Note that all remaining kwargs must be compatible with ``.dist()``
 
@@ -477,7 +481,6 @@ class Distribution(metaclass=DistributionMeta):
         rv : TensorVariable
             The created random variable tensor, registered in the Model.
         """
-
         try:
             from pymc.model import Model
 
@@ -533,7 +536,7 @@ class Distribution(metaclass=DistributionMeta):
         shape: Shape | None = None,
         **kwargs,
     ) -> TensorVariable:
-        """Creates a tensor variable corresponding to the `cls` distribution.
+        """Create a tensor variable corresponding to the `cls` distribution.
 
         Parameters
         ----------
@@ -582,13 +585,10 @@ class Distribution(metaclass=DistributionMeta):
 
 @node_rewriter([SymbolicRandomVariable])
 def inline_symbolic_random_variable(fgraph, node):
-    """
-    Optimization that expands the internal graph of a SymbolicRV when obtaining the logp
-    graph, if the flag `inline_logprob` is True.
-    """
+    """Expand a SymbolicRV when obtaining the logp graph if `inline_logprob` is True."""
     op = node.op
     if op.inline_logprob:
-        return clone_replace(op.inner_outputs, {u: v for u, v in zip(op.inner_inputs, node.inputs)})
+        return clone_replace(op.inner_outputs, dict(zip(op.inner_inputs, node.inputs)))
 
 
 # Registered before pre-canonicalization which happens at position=-10
@@ -606,8 +606,7 @@ def _support_point(op, rv, *rv_inputs) -> TensorVariable:
 
 
 def support_point(rv: TensorVariable) -> TensorVariable:
-    """Method for choosing a representative point/value
-    that can be used to start optimization or MCMC sampling.
+    """Choose a representative point/value that can be used to start optimization or MCMC sampling.
 
     The only parameter to this function is the RandomVariable
     for which the value is to be derived.
@@ -632,7 +631,7 @@ def moment(rv: TensorVariable) -> TensorVariable:
 
 
 class Discrete(Distribution):
-    """Base class for discrete distributions"""
+    """Base class for discrete distributions."""
 
     def __new__(cls, name, *args, **kwargs):
         if kwargs.get("transform", None):
@@ -642,7 +641,7 @@ class Discrete(Distribution):
 
 
 class Continuous(Distribution):
-    """Base class for continuous distributions"""
+    """Base class for continuous distributions."""
 
 
 class DiracDeltaRV(SymbolicRandomVariable):
