@@ -35,9 +35,12 @@ PointType = dict[str, np.ndarray]
 def convert_str_to_rv_dict(
     model, start: StartDict
 ) -> dict[TensorVariable, np.ndarray | Variable | str | None]:
-    """Helper function for converting a user-provided start dict with str keys of (transformed) variable names
+    """Convert a user-provided start dict to an untransformed RV start dict.
+
+    Converts a dict of str keys of (transformed) variable names
     to a dict mapping the RV tensors to untransformed initvals.
-    TODO: Deprecate this functionality and only accept TensorVariables as keys
+
+    TODO: Deprecate this functionality and only accept TensorVariables as keys.
     """
     initvals = {}
     for key, initval in start.items():
@@ -59,7 +62,7 @@ def make_initial_point_fns_per_chain(
     jitter_rvs: set[TensorVariable] | None = None,
     chains: int,
 ) -> list[Callable]:
-    """Create an initial point function for each chain, as defined by initvals
+    """Create an initial point function for each chain, as defined by initvals.
 
     If a single initval dictionary is passed, the function is replicated for each
     chain, otherwise a unique function is compiled for each entry in the dictionary.
@@ -130,7 +133,6 @@ def make_initial_point_fn(
     return_transformed : bool
         If `True` the returned variables will correspond to transformed initial values.
     """
-
     sdict_overrides = convert_str_to_rv_dict(model, overrides or {})
     initval_strats = {
         **model.rvs_to_initial_values,
@@ -183,7 +185,7 @@ def make_initial_point_expression(
     default_strategy: str = "support_point",
     return_transformed: bool = False,
 ) -> list[TensorVariable]:
-    """Creates the tensor variables that need to be evaluated to obtain an initial point.
+    """Create the tensor variables that need to be evaluated to obtain an initial point.
 
     Parameters
     ----------
