@@ -16,6 +16,7 @@ import functools
 import warnings
 
 from collections.abc import Sequence
+from copy import deepcopy
 from typing import NewType, cast
 
 import arviz
@@ -70,7 +71,7 @@ UNSET = _UnsetType()
 
 
 def withparent(meth):
-    """Helper wrapper that passes calls to parent's instance"""
+    """Pass calls to parent's instance."""
 
     def wrapped(self, *args, **kwargs):
         res = meth(self, *args, **kwargs)
@@ -86,9 +87,9 @@ def withparent(meth):
 
 
 class treelist(list):
-    """A list that passes mutable extending operations used in Model
-    to parent list instance.
-    Extending treelist you will also extend its parent
+    """A list that passes mutable extending operations used in Model to parent list instance.
+
+    Extending treelist you will also extend its parent.
     """
 
     def __init__(self, iterable=(), parent=None):
@@ -98,7 +99,7 @@ class treelist(list):
         if self.parent is not None:
             self.parent.extend(self)
 
-    # typechecking here works bad
+    # here typechecking works bad
     append = withparent(list.append)
     __iadd__ = withparent(list.__iadd__)
     extend = withparent(list.extend)
@@ -112,6 +113,7 @@ class treelist(list):
             return list.__contains__(self, item)
 
     def __setitem__(self, key, value):
+        """Set value at index `key` with value `value`."""
         raise NotImplementedError(
             "Method is removed as we are not able to determine appropriate logic for it"
         )
@@ -120,9 +122,11 @@ class treelist(list):
     # This is my best guess about what this should do.  I might be happier
     # to kill both of these if they are not used.
     def __mul__(self, other) -> "treelist":
+        """Multiplication."""
         return cast("treelist", super().__mul__(other))
 
     def __imul__(self, other) -> "treelist":
+        """Inplace multiplication."""
         t0 = len(self)
         super().__imul__(other)
         if self.parent is not None:
@@ -131,9 +135,9 @@ class treelist(list):
 
 
 class treedict(dict):
-    """A dict that passes mutable extending operations used in Model
-    to parent dict instance.
-    Extending treedict you will also extend its parent
+    """A dict that passes mutable extending operations used in Model to parent dict instance.
+
+    Extending treedict you will also extend its parent.
     """
 
     def __init__(self, iterable=(), parent=None, **kwargs):
@@ -143,7 +147,7 @@ class treedict(dict):
         if self.parent is not None:
             self.parent.update(self)
 
-    # typechecking here works bad
+    # here typechecking works bad
     __setitem__ = withparent(dict.__setitem__)
     update = withparent(dict.update)
 
@@ -159,7 +163,7 @@ class treedict(dict):
 
 def get_transformed_name(name, transform):
     r"""
-    Consistent way of transforming names
+    Consistent way of transforming names.
 
     Parameters
     ----------
@@ -178,7 +182,7 @@ def get_transformed_name(name, transform):
 
 def is_transformed_name(name):
     r"""
-    Quickly check if a name was transformed with `get_transformed_name`
+    Quickly check if a name was transformed with `get_transformed_name`.
 
     Parameters
     ----------
@@ -195,7 +199,7 @@ def is_transformed_name(name):
 
 def get_untransformed_name(name):
     r"""
-    Undo transformation in `get_transformed_name`. Throws ValueError if name wasn't transformed
+    Undo transformation in `get_transformed_name`. Throws ValueError if name wasn't transformed.
 
     Parameters
     ----------
@@ -213,7 +217,7 @@ def get_untransformed_name(name):
 
 
 def get_default_varnames(var_iterator, include_transformed):
-    r"""Helper to extract default varnames from a trace.
+    r"""Extract default varnames from a trace.
 
     Parameters
     ----------
@@ -263,7 +267,7 @@ def biwrap(wrapper):
 
 
 def drop_warning_stat(idata: arviz.InferenceData) -> arviz.InferenceData:
-    """Returns a new ``InferenceData`` object with the "warning" stat removed from sample stats groups.
+    """Return a new ``InferenceData`` object with the "warning" stat removed from sample stats groups.
 
     This function should be applied to an ``InferenceData`` object obtained with
     ``pm.sample(keep_warning_stat=True)`` before trying to ``.to_netcdf()`` or ``.to_zarr()`` it.
@@ -297,7 +301,8 @@ def chains_and_samples(data: xarray.Dataset | arviz.InferenceData) -> tuple[int,
 
 def hashable(a=None) -> int:
     """
-    Hashes many kinds of objects, including some that are unhashable through the builtin `hash` function.
+    Hash many kinds of objects, including some that are unhashable through the builtin `hash` function.
+
     Lists and tuples are hashed based on their elements.
     """
     if isinstance(a, dict):
@@ -333,25 +338,31 @@ class HashableWrapper:
         self.obj = obj
 
     def __hash__(self):
+        """Return a hash of the object."""
         return hashable(self.obj)
 
     def __eq__(self, other):
+        """Compare this object with `other`."""
         return self.obj == other
 
     def __repr__(self):
+        """Return a string representation of the object."""
         return f"{type(self).__name__}({self.obj})"
 
 
 class WithMemoization:
     def __hash__(self):
+        """Return a hash of the object."""
         return hash(id(self))
 
     def __getstate__(self):
+        """Return an object to pickle."""
         state = self.__dict__.copy()
         state.pop("_cache", None)
         return state
 
     def __setstate__(self, state):
+        """Set the object from a pickled object."""
         self.__dict__.update(state)
 
 
@@ -368,7 +379,7 @@ def locally_cachedmethod(f):
 
 
 def check_dist_not_registered(dist, model=None):
-    """Check that a dist is not registered in the model already"""
+    """Check that a dist is not registered in the model already."""
     from pymc.model import modelcontext
 
     try:
@@ -385,8 +396,10 @@ def check_dist_not_registered(dist, model=None):
 
 
 def point_wrapper(core_function):
-    """Wrap an pytensor compiled function to be able to ingest point dictionaries whilst
-    ignoring the keys that are not valid inputs to the core function.
+    """
+    Wrap a pytensor compiled function to ingest point dictionaries.
+
+    It ignores the keys that are not valid inputs to the core function.
     """
     ins = [i.name for i in core_function.maker.fgraph.inputs if not isinstance(i, SharedVariable)]
 
@@ -399,6 +412,7 @@ def point_wrapper(core_function):
 
 RandomSeed = None | int | Sequence[int] | np.ndarray
 RandomState = RandomSeed | np.random.RandomState | np.random.Generator
+RandomGenerator = RandomSeed | np.random.Generator | np.random.BitGenerator
 
 
 def _get_seeds_per_chain(
@@ -431,10 +445,15 @@ def _get_seeds_per_chain(
             seeds = [int(seed) for seed in integers_fn(2**30, dtype=np.int64, size=chains)]
         return seeds
 
-    if random_state is None or isinstance(random_state, int):
-        if chains == 1 and isinstance(random_state, int):
-            return (random_state,)
-        return _get_unique_seeds_per_chain(np.random.default_rng(random_state).integers)
+    try:
+        int_random_state = int(random_state)  # type: ignore[arg-type]
+    except Exception:
+        int_random_state = None
+
+    if random_state is None or int_random_state is not None:
+        if chains == 1 and int_random_state is not None:
+            return (int_random_state,)
+        return _get_unique_seeds_per_chain(np.random.default_rng(int_random_state).integers)
     if isinstance(random_state, np.random.Generator):
         return _get_unique_seeds_per_chain(random_state.integers)
     if isinstance(random_state, np.random.RandomState):
@@ -452,7 +471,7 @@ def _get_seeds_per_chain(
 
 
 def get_value_vars_from_user_vars(vars: Variable | Sequence[Variable], model) -> list[Variable]:
-    """Converts user "vars" input into value variables.
+    """Convert user "vars" input into value variables.
 
     More often than not, users will pass random variables, and we will extract the
     respective value variables, but we also allow for the input to already be value
@@ -524,7 +543,7 @@ def makeiter(a):
 
 
 class CustomProgress(Progress):
-    """A child of Progress that allows to disable progress bars and its container
+    """A child of Progress that allows to disable progress bars and its container.
 
     The implementation simply checks an `is_enabled` flag and generates the progress bar only if
     it's `True`.
@@ -536,11 +555,13 @@ class CustomProgress(Progress):
             super().__init__(*args, **kwargs)
 
     def __enter__(self):
+        """Enter the context manager."""
         if self.is_enabled:
             self.start()
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
+        """Exit the context manager."""
         if self.is_enabled:
             super().__exit__(exc_type, exc_val, exc_tb)
 
@@ -578,3 +599,52 @@ class CustomProgress(Progress):
                 **fields,
             )
         return None
+
+
+def get_random_generator(
+    seed: RandomGenerator | np.random.RandomState = None, copy: bool = True
+) -> np.random.Generator:
+    """Build a :py:class:`~numpy.random.Generator` object from a suitable seed.
+
+    Parameters
+    ----------
+    seed : None | int | Sequence[int] | numpy.random.Generator | numpy.random.BitGenerator | numpy.random.RandomState
+        A suitable seed to use to generate the :py:class:`~numpy.random.Generator` object.
+        For more details on suitable seeds, refer to :py:func:`numpy.random.default_rng`.
+    copy : bool
+        Boolean flag that indicates whether to copy the seed object before feeding
+        it to :py:func:`numpy.random.default_rng`. If `copy` is `False`, and the seed
+        object is a ``BitGenerator`` or ``Generator`` object, the returned
+        ``Generator`` will use the ``seed`` object where possible. This means that it
+        will return the ``seed`` input object if it is a ``Generator`` or that it
+        will return a new ``Generator`` whose ``bit_generator`` attribute will be the
+        input ``seed`` object. To avoid this potential object sharing, you must set
+        ``copy`` to ``True``.
+
+    Returns
+    -------
+    rng : numpy.random.Generator
+        The result of passing the input ``seed`` (or a copy of it) through
+        :py:func:`numpy.random.default_rng`.
+
+    Raises
+    ------
+    TypeError:
+        If the supplied ``seed`` is a :py:class:`~numpy.random.RandomState` object. We
+        do not support using these legacy objects because their seeding strategy is not
+        amenable to spawning new independent random streams.
+    """
+    if isinstance(seed, np.random.RandomState):
+        raise TypeError(
+            "Cannot create a random Generator from a RandomStream object. "
+            "Please provide a random seed, BitGenerator or Generator instead."
+        )
+    if copy:
+        # If seed is a numpy.random.Generator or numpy.random.BitGenerator,
+        # numpy.random.default_rng will use the exact same object to return.
+        # In the former case, it will return seed, in the latter it will return
+        # a new Generator object that has the same BitGenerator. This would potentially
+        # make the new generator be shared across many users. To avoid this, we
+        # deepcopy by default.
+        seed = deepcopy(seed)
+    return np.random.default_rng(seed)
