@@ -13,9 +13,7 @@
 #   limitations under the License.
 
 #!/usr/bin/env python
-"""
-A setup.py script to use setuptools, which gives egg goodness, etc.
-"""
+"""A setup.py script to use setuptools, which gives egg goodness, etc."""
 
 with open("setup.py") as s:
     exec(s.read())
