@@ -62,9 +62,7 @@ _n2 = _b + _n + _m2.sum()
     ],  # all missing -> partial
     ids=["all_params", "missing_loss", "missing_params", "all_missing"],
 )
-@pytest.mark.parametrize(
-    "kwargs", [dict(), dict(learning_rate=1e-2)], ids=["without_args", "with_args"]
-)
+@pytest.mark.parametrize("kwargs", [{}, {"learning_rate": 1e-2}], ids=["without_args", "with_args"])
 @pytest.mark.parametrize(
     "loss_and_params",
     [(_b, [_a]), (_n, [_m]), (_n2, [_a, _m, _m2])],
@@ -73,9 +71,9 @@ _n2 = _b + _n + _m2.sum()
 def test_updates_fast(opt, loss_and_params, kwargs, getter):
     with pytensor.config.change_flags(compute_test_value="ignore"):
         loss, param = getter(loss_and_params)
-        args = dict()
+        args = {}
         args.update(**kwargs)
-        args.update(dict(loss_or_grads=loss, params=param))
+        args.update({"loss_or_grads": loss, "params": param})
         if loss is None and param is None:
             updates = opt(**args)
             # Here we should get new callable
